# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from .x_array import XArray as XArray_708108fb
    from .x_blob import XBlob as XBlob_6773087b
    from .x_clob import XClob as XClob_6777087c
    from .x_ref import XRef as XRef_5f110819
    from ..util.date import Date as Date_60040844
    from ..util.date_time import DateTime as DateTime_84de09d3
    from ..util.time import Time as Time_604e0855

class XRow(XInterface_8f010a43):
    """
    is used to access data which is collected in a row.
    
    All methods raise a com.sun.star.sdbc.SQLException if a database access error occurs.

    See Also:
        `API XRow <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XRow.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XRow'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XRow'

    @abstractmethod
    def getArray(self, columnIndex: int) -> XArray_708108fb:
        """
        gets a SQL ARRAY value from the current row of this ResultSet object.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getBinaryStream(self, columnIndex: int) -> XInputStream_98d40ab4:
        """
        gets the value of a column in the current row as a stream of uninterpreted bytes.
        
        The value can then be read in chunks from the stream. This method is particularly suitable for retrieving large LONGVARBINARY values.
        
        Note: All the data in the returned stream must be read prior to getting the value of any other column. The next call to a get method implicitly closes the stream. Also, a stream may return 0 when the method com.sun.star.io.XInputStream.available() is called whether there is data available or not.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getBlob(self, columnIndex: int) -> XBlob_6773087b:
        """
        gets a BLOB value in the current row.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getBoolean(self, columnIndex: int) -> bool:
        """
        gets the value of a column in the current row as boolean.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getByte(self, columnIndex: int) -> int:
        """
        get the value of a column in the current row as a byte.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getBytes(self, columnIndex: int) -> uno.ByteSequence:
        """
        gets the value of a column in the current row as a byte array.
        
        The bytes represent the raw values returned by the driver.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getCharacterStream(self, columnIndex: int) -> XInputStream_98d40ab4:
        """
        gets the value of a column in the current row as a stream of uninterpreted bytes.
        
        The value can then be read in chunks from the stream. This method is particularly suitable for retrieving large LONGVARBINARY or LONGVARCHAR values.
        
        Note: All the data in the returned stream must be read prior to getting the value of any other column. The next call to a get method implicitly closes the stream. Also, a stream may return 0 when the method com.sun.star.io.XInputStream.available() is called whether there is data available or not.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getClob(self, columnIndex: int) -> XClob_6777087c:
        """
        gets a CLOB value in the current row of this ResultSet object.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getDate(self, columnIndex: int) -> Date_60040844:
        """
        gets the value of a column in the current row as a date object.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getDouble(self, columnIndex: int) -> float:
        """
        gets the value of a column in the current row as a double.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getFloat(self, columnIndex: int) -> float:
        """
        gets the value of a column in the current row as a float.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getInt(self, columnIndex: int) -> int:
        """
        get the value of a column in the current row as an integer.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getLong(self, columnIndex: int) -> int:
        """
        get the value of a column in the current row as a long.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getObject(self, columnIndex: int, typeMap: XNameAccess_e2ab0cf6) -> object:
        """
        returns the value of a column in the current row as an object.
        
        This method uses the given Map object for the custom mapping of the SQL structure or distinct type that is being retrieved.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getRef(self, columnIndex: int) -> XRef_5f110819:
        """
        gets a REF(&lt;structured-type&gt;) column value from the current row.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getShort(self, columnIndex: int) -> int:
        """
        gets the value of a column in the current row as a short.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getString(self, columnIndex: int) -> str:
        """
        gets the value of a column in the current row as a string.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getTime(self, columnIndex: int) -> Time_604e0855:
        """
        gets the value of a column in the current row as a time object.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getTimestamp(self, columnIndex: int) -> DateTime_84de09d3:
        """
        gets the value of a column in the current row as a datetime object.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def wasNull(self) -> bool:
        """
        reports whether the last column read had a value of SQL NULL.
        
        Note that you must first call getXXX on a column to try to read its value and then call wasNull() to see if the value read was SQL NULL.

        Raises:
            SQLException: ``SQLException``
        """
        ...

__all__ = ['XRow']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class RectanglePoint(metaclass=UnoEnumMeta, type_name="com.sun.star.drawing.RectanglePoint", name_space="com.sun.star.drawing"):
        """Dynamically created class that represents ``com.sun.star.drawing.RectanglePoint`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.drawing.RectanglePoint import LEFT_BOTTOM as RECTANGLE_POINT_LEFT_BOTTOM
        from com.sun.star.drawing.RectanglePoint import LEFT_MIDDLE as RECTANGLE_POINT_LEFT_MIDDLE
        from com.sun.star.drawing.RectanglePoint import LEFT_TOP as RECTANGLE_POINT_LEFT_TOP
        from com.sun.star.drawing.RectanglePoint import MIDDLE_BOTTOM as RECTANGLE_POINT_MIDDLE_BOTTOM
        from com.sun.star.drawing.RectanglePoint import MIDDLE_MIDDLE as RECTANGLE_POINT_MIDDLE_MIDDLE
        from com.sun.star.drawing.RectanglePoint import MIDDLE_TOP as RECTANGLE_POINT_MIDDLE_TOP
        from com.sun.star.drawing.RectanglePoint import RIGHT_BOTTOM as RECTANGLE_POINT_RIGHT_BOTTOM
        from com.sun.star.drawing.RectanglePoint import RIGHT_MIDDLE as RECTANGLE_POINT_RIGHT_MIDDLE
        from com.sun.star.drawing.RectanglePoint import RIGHT_TOP as RECTANGLE_POINT_RIGHT_TOP

        class RectanglePoint(uno.Enum):
            """
            Enum Class


            See Also:
                `API RectanglePoint <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.drawing.RectanglePoint', value)

            __ooo_ns__: str = 'com.sun.star.drawing'
            __ooo_full_ns__: str = 'com.sun.star.drawing.RectanglePoint'
            __ooo_type_name__: str = 'enum'

            LEFT_BOTTOM = RECTANGLE_POINT_LEFT_BOTTOM
            """
            specify to the point on the bottom of the left side from the rectangle.
            """
            LEFT_MIDDLE = RECTANGLE_POINT_LEFT_MIDDLE
            """
            specify to the point on the middle of the left side from the rectangle.
            """
            LEFT_TOP = RECTANGLE_POINT_LEFT_TOP
            """
            specify to the point on the left side from the top of the rectangle.
            """
            MIDDLE_BOTTOM = RECTANGLE_POINT_MIDDLE_BOTTOM
            """
            specify to the point on the middle of the bottom from the rectangle.
            """
            MIDDLE_MIDDLE = RECTANGLE_POINT_MIDDLE_MIDDLE
            """
            specify to the point on the center from the rectangle.
            """
            MIDDLE_TOP = RECTANGLE_POINT_MIDDLE_TOP
            """
            specify to the point on the middle of the top from the rectangle.
            """
            RIGHT_BOTTOM = RECTANGLE_POINT_RIGHT_BOTTOM
            """
            specify to the point on the bottom of the right side from the rectangle.
            """
            RIGHT_MIDDLE = RECTANGLE_POINT_RIGHT_MIDDLE
            """
            specify to the point on the middle of the right side from the rectangle.
            """
            RIGHT_TOP = RECTANGLE_POINT_RIGHT_TOP
            """
            specify to the point on the right side from the top of the rectangle.
            """
    else:
        # keep document generators happy
        from ...lo.drawing.rectangle_point import RectanglePoint as RectanglePoint


__all__ = ['RectanglePoint']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ....lo.configuration.backend.authentication_failed_exception import AuthenticationFailedException as AuthenticationFailedException
from ....lo.configuration.backend.backend import Backend as Backend
from ....lo.configuration.backend.backend_access_exception import BackendAccessException as BackendAccessException
from ....lo.configuration.backend.backend_adapter import BackendAdapter as BackendAdapter
from ....lo.configuration.backend.backend_setup_exception import BackendSetupException as BackendSetupException
from ....lo.configuration.backend.cannot_connect_exception import CannotConnectException as CannotConnectException
from ....lo.configuration.backend.component_change_event import ComponentChangeEvent as ComponentChangeEvent
from ....lo.configuration.backend.connection_lost_exception import ConnectionLostException as ConnectionLostException
from ....lo.configuration.backend.copy_importer import CopyImporter as CopyImporter
from ....lo.configuration.backend.data_importer import DataImporter as DataImporter
from ....lo.configuration.backend.default_backend import DefaultBackend as DefaultBackend
from ....lo.configuration.backend.hierarchy_browser import HierarchyBrowser as HierarchyBrowser
from ....lo.configuration.backend.importer import Importer as Importer
from ....lo.configuration.backend.insufficient_access_rights_exception import InsufficientAccessRightsException as InsufficientAccessRightsException
from ....lo.configuration.backend.interaction_handler import InteractionHandler as InteractionHandler
from ....lo.configuration.backend.invalid_authentication_mechanism_exception import InvalidAuthenticationMechanismException as InvalidAuthenticationMechanismException
from ....lo.configuration.backend.layer import Layer as Layer
from ....lo.configuration.backend.layer_describer import LayerDescriber as LayerDescriber
from ....lo.configuration.backend.layer_filter import LayerFilter as LayerFilter
from ....lo.configuration.backend.layer_update_merger import LayerUpdateMerger as LayerUpdateMerger
from ....lo.configuration.backend.ldap_multi_layer_stratum import LdapMultiLayerStratum as LdapMultiLayerStratum
from ....lo.configuration.backend.ldap_single_backend import LdapSingleBackend as LdapSingleBackend
from ....lo.configuration.backend.ldap_single_stratum import LdapSingleStratum as LdapSingleStratum
from ....lo.configuration.backend.local_data_importer import LocalDataImporter as LocalDataImporter
from ....lo.configuration.backend.local_hierarchy_browser import LocalHierarchyBrowser as LocalHierarchyBrowser
from ....lo.configuration.backend.local_schema_supplier import LocalSchemaSupplier as LocalSchemaSupplier
from ....lo.configuration.backend.local_single_backend import LocalSingleBackend as LocalSingleBackend
from ....lo.configuration.backend.local_single_stratum import LocalSingleStratum as LocalSingleStratum
from ....lo.configuration.backend.malformed_data_exception import MalformedDataException as MalformedDataException
from ....lo.configuration.backend.merge_importer import MergeImporter as MergeImporter
from ....lo.configuration.backend.merge_recovery_request import MergeRecoveryRequest as MergeRecoveryRequest
from ....lo.configuration.backend.multi_layer_stratum import MultiLayerStratum as MultiLayerStratum
from ....lo.configuration.backend.multi_stratum_backend import MultiStratumBackend as MultiStratumBackend
from ....lo.configuration.backend.node_attribute import NodeAttribute as NodeAttribute
from ....lo.configuration.backend.offline_backend import OfflineBackend as OfflineBackend
from ....lo.configuration.backend.online_backend import OnlineBackend as OnlineBackend
from ....lo.configuration.backend.platform_backend import PlatformBackend as PlatformBackend
from ....lo.configuration.backend.property_info import PropertyInfo as PropertyInfo
from ....lo.configuration.backend.schema import Schema as Schema
from ....lo.configuration.backend.schema_attribute import SchemaAttribute as SchemaAttribute
from ....lo.configuration.backend.schema_supplier import SchemaSupplier as SchemaSupplier
from ....lo.configuration.backend.single_backend import SingleBackend as SingleBackend
from ....lo.configuration.backend.single_backend_adapter import SingleBackendAdapter as SingleBackendAdapter
from ....lo.configuration.backend.single_layer_stratum import SingleLayerStratum as SingleLayerStratum
from ....lo.configuration.backend.stratum_creation_exception import StratumCreationException as StratumCreationException
from ....lo.configuration.backend.system_integration import SystemIntegration as SystemIntegration
from ....lo.configuration.backend.template_identifier import TemplateIdentifier as TemplateIdentifier
from ....lo.configuration.backend.updatable_layer import UpdatableLayer as UpdatableLayer
from ....lo.configuration.backend.x_backend import XBackend as XBackend
from ....lo.configuration.backend.x_backend_changes_listener import XBackendChangesListener as XBackendChangesListener
from ....lo.configuration.backend.x_backend_changes_notifier import XBackendChangesNotifier as XBackendChangesNotifier
from ....lo.configuration.backend.x_backend_entities import XBackendEntities as XBackendEntities
from ....lo.configuration.backend.x_composite_layer import XCompositeLayer as XCompositeLayer
from ....lo.configuration.backend.x_layer import XLayer as XLayer
from ....lo.configuration.backend.x_layer_content_describer import XLayerContentDescriber as XLayerContentDescriber
from ....lo.configuration.backend.x_layer_handler import XLayerHandler as XLayerHandler
from ....lo.configuration.backend.x_layer_importer import XLayerImporter as XLayerImporter
from ....lo.configuration.backend.x_multi_layer_stratum import XMultiLayerStratum as XMultiLayerStratum
from ....lo.configuration.backend.x_schema import XSchema as XSchema
from ....lo.configuration.backend.x_schema_handler import XSchemaHandler as XSchemaHandler
from ....lo.configuration.backend.x_schema_supplier import XSchemaSupplier as XSchemaSupplier
from ....lo.configuration.backend.x_single_layer_stratum import XSingleLayerStratum as XSingleLayerStratum
from ....lo.configuration.backend.x_updatable_layer import XUpdatableLayer as XUpdatableLayer
from ....lo.configuration.backend.x_update_handler import XUpdateHandler as XUpdateHandler
from ....lo.configuration.backend.x_versioned_schema_supplier import XVersionedSchemaSupplier as XVersionedSchemaSupplier



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_canvas import XCanvas as XCanvas_b19b0b7a
if typing.TYPE_CHECKING:
    from ..geometry.real_rectangle2_d import RealRectangle2D as RealRectangle2D_d9b0e03
    from .render_state import RenderState as RenderState_e4490d27
    from .view_state import ViewState as ViewState_cab30c62

class XBitmapCanvas(XCanvas_b19b0b7a):
    """
    This is a specialization of the canvas interface for bitmapped canvases.
    
    This interface is a specialization of the canvas interface for bitmapped canvases, where additional methods for accessing and moving of bitmap content are provided.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XBitmapCanvas <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XBitmapCanvas.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.XBitmapCanvas'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rendering.XBitmapCanvas'

    @abstractmethod
    def copyRect(self, sourceCanvas: XBitmapCanvas, sourceRect: RealRectangle2D_d9b0e03, sourceViewState: ViewState_cab30c62, sourceRenderState: RenderState_e4490d27, destRect: RealRectangle2D_d9b0e03, destViewState: ViewState_cab30c62, destRenderState: RenderState_e4490d27) -> None:
        """
        This method copies a rectangular area from a place of one canvas to a place on another.
        
        This method copies a rectangular area from a place of one canvas to a place on another. Source and destination areas are permitted to overlap. If the source view or render state has a clipping set, the regions clipped away from the source rectangle are regarded fully transparent for the copy operation. The device color for both source and destination render state is ignored, the compositing mode only for the source render state.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            VolatileContentDestroyedException: ``VolatileContentDestroyedException``
        """
        ...

__all__ = ['XBitmapCanvas']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class TableColumnSeparator(object):
    """
    Struct Class

    The width of the cells of a text table is defined by the position of the separator between neighboring cells.
    
    If cells of the table are merged, this separator is not removed, but it is hidden.
    
    A text table or a text table row provides the separators in a sequence of TableColumnSeparators. If the table only consists of one column, then this sequence is empty.
    
    The real width of a table depends on the environment (page style and number of text columns at the table's position, alignment, and left and right margins). For that reason, the table column separator does not contain metric values for the column widths. The values are relative to the value of the property TextTable.TableColumnRelativeSum.
    
    A table provides this property only if all rows have the same structure. If the table does not provide the property, then it cannot be set using.
    
    The state of TableColumnSeparator.IsVisible and the count of the sequence must be the same in as it was in. Hidden separators cannot be moved and they cannot be overtaken by visible separators.

    See Also:
        `API TableColumnSeparator <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1text_1_1TableColumnSeparator.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.TableColumnSeparator'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.text.TableColumnSeparator'
    """Literal Constant ``com.sun.star.text.TableColumnSeparator``"""

    def __init__(self, Position: typing.Optional[int] = 0, IsVisible: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            Position (int, optional): Position value.
            IsVisible (bool, optional): IsVisible value.
        """
        super().__init__()

        if isinstance(Position, TableColumnSeparator):
            oth: TableColumnSeparator = Position
            self.Position = oth.Position
            self.IsVisible = oth.IsVisible
            return

        kargs = {
            "Position": Position,
            "IsVisible": IsVisible,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._position = kwargs["Position"]
        self._is_visible = kwargs["IsVisible"]


    @property
    def Position(self) -> int:
        """
        contains the position of the separator.
        """
        return self._position

    @Position.setter
    def Position(self, value: int) -> None:
        self._position = value

    @property
    def IsVisible(self) -> bool:
        """
        determines if the separator is visible.
        """
        return self._is_visible

    @IsVisible.setter
    def IsVisible(self, value: bool) -> None:
        self._is_visible = value


__all__ = ['TableColumnSeparator']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class FrameAction(metaclass=UnoEnumMeta, type_name="com.sun.star.frame.FrameAction", name_space="com.sun.star.frame"):
        """Dynamically created class that represents ``com.sun.star.frame.FrameAction`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.frame.FrameAction import COMPONENT_ATTACHED as FRAME_ACTION_COMPONENT_ATTACHED
        from com.sun.star.frame.FrameAction import COMPONENT_DETACHING as FRAME_ACTION_COMPONENT_DETACHING
        from com.sun.star.frame.FrameAction import COMPONENT_REATTACHED as FRAME_ACTION_COMPONENT_REATTACHED
        from com.sun.star.frame.FrameAction import CONTEXT_CHANGED as FRAME_ACTION_CONTEXT_CHANGED
        from com.sun.star.frame.FrameAction import FRAME_ACTIVATED as FRAME_ACTION_FRAME_ACTIVATED
        from com.sun.star.frame.FrameAction import FRAME_DEACTIVATING as FRAME_ACTION_FRAME_DEACTIVATING
        from com.sun.star.frame.FrameAction import FRAME_UI_ACTIVATED as FRAME_ACTION_FRAME_UI_ACTIVATED
        from com.sun.star.frame.FrameAction import FRAME_UI_DEACTIVATING as FRAME_ACTION_FRAME_UI_DEACTIVATING

        class FrameAction(uno.Enum):
            """
            Enum Class


            See Also:
                `API FrameAction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1frame.html#a793fdb3e5cab69d63a9c89b5e4f83dfd>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.frame.FrameAction', value)

            __ooo_ns__: str = 'com.sun.star.frame'
            __ooo_full_ns__: str = 'com.sun.star.frame.FrameAction'
            __ooo_type_name__: str = 'enum'

            COMPONENT_ATTACHED = FRAME_ACTION_COMPONENT_ATTACHED
            """
            an event of this kind is broadcast whenever a component is attached to a frame

            This is almost the same as the instantiation of the component within that frame. The component is attached to the frame immediately before this event is broadcast.
            """
            COMPONENT_DETACHING = FRAME_ACTION_COMPONENT_DETACHING
            """
            an event of this kind is broadcast whenever a component is detaching from a frame

            This is quite the same as the destruction of the component which was in that frame. At the moment when the event is broadcast the component is still attached to the frame but in the next moment it won't.
            """
            COMPONENT_REATTACHED = FRAME_ACTION_COMPONENT_REATTACHED
            """
            an event of this kind is broadcast whenever a component is attached to a new model.

            In this case the component remains the same but operates on a new model component.
            """
            CONTEXT_CHANGED = FRAME_ACTION_CONTEXT_CHANGED
            """
            an event of this kind is broadcast whenever a component changes its internal context (i.e., the selection).

            If the activation status within a frame changes, this counts as a context change too.
            """
            FRAME_ACTIVATED = FRAME_ACTION_FRAME_ACTIVATED
            """
            an event of this kind is broadcast whenever a component gets activated

            Activations are broadcast from the top component which was not active before, down to the inner most component.
            """
            FRAME_DEACTIVATING = FRAME_ACTION_FRAME_DEACTIVATING
            """
            an event of this kind is broadcasted immediately before the component is deactivated

            Deactivations are broadcast from the innermost component which does not stay active up to the outer most component which does not stay active.
            """
            FRAME_UI_ACTIVATED = FRAME_ACTION_FRAME_UI_ACTIVATED
            """
            an event of this kind is broadcast by an active frame when it is getting UI control (tool control).
            """
            FRAME_UI_DEACTIVATING = FRAME_ACTION_FRAME_UI_DEACTIVATING
            """
            an event of this kind is broadcast by an active frame when it is losing UI control (tool control).
            """
    else:
        # keep document generators happy
        from ...lo.frame.frame_action import FrameAction as FrameAction


__all__ = ['FrameAction']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sdbc
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..uno.exception import Exception as Exception_85530a09
from ..uno.x_interface import XInterface as XInterface_8f010a43

class SQLException(Exception_85530a09):
    """
    Exception Class

    is an exception that provides information on a database access error.
    
    Each com.sun.star.sdbc.SQLException provides several kinds of information:

    See Also:
        `API SQLException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.SQLException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.sdbc.SQLException'
    __pyunostruct__: str = 'com.sun.star.sdbc.SQLException'

    typeName: str = 'com.sun.star.sdbc.SQLException'
    """Literal Constant ``com.sun.star.sdbc.SQLException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, SQLState: typing.Optional[str] = '', ErrorCode: typing.Optional[int] = 0, NextException: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            SQLState (str, optional): SQLState value.
            ErrorCode (int, optional): ErrorCode value.
            NextException (object, optional): NextException value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "SQLState": SQLState,
            "ErrorCode": ErrorCode,
            "NextException": NextException,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._sql_state = kwargs["SQLState"]
        self._error_code = kwargs["ErrorCode"]
        self._next_exception = kwargs["NextException"]
        inst_keys = ('SQLState', 'ErrorCode', 'NextException')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def SQLState(self) -> str:
        """
        returns a string, which uses the XOPEN SQLState conventions.
        
        The values of the SQLState string are described in the XOPEN SQL spec.
        """
        return self._sql_state
    
    @SQLState.setter
    def SQLState(self, value: str) -> None:
        self._sql_state = value

    @property
    def ErrorCode(self) -> int:
        """
        returns an integer error code that is specific to each vendor.
        
        Normally this will be the actual error code returned by the underlying database.
        """
        return self._error_code
    
    @ErrorCode.setter
    def ErrorCode(self, value: int) -> None:
        self._error_code = value

    @property
    def NextException(self) -> object:
        """
        returns a chain to the next Exception.
        
        This can be used to provide additional error information.
        """
        return self._next_exception
    
    @NextException.setter
    def NextException(self, value: object) -> None:
        self._next_exception = value


__all__ = ['SQLException']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui.dialogs
from __future__ import annotations
from ...lang.x_component import XComponent as XComponent_98dc0ab5
from .x_file_picker2 import XFilePicker2 as XFilePicker2_f99d0d5f
from .x_file_picker_notifier import XFilePickerNotifier as XFilePickerNotifier_6402106d
from .x_file_preview import XFilePreview as XFilePreview_fa400db1
from .x_filter_group_manager import XFilterGroupManager as XFilterGroupManager_65a9107d
from .x_filter_manager import XFilterManager as XFilterManager_16f30e70
from ...util.x_cancellable import XCancellable as XCancellable_afc30b64

class XFilePicker3(XComponent_98dc0ab5, XFilePicker2_f99d0d5f, XFilePickerNotifier_6402106d, XFilePreview_fa400db1, XFilterGroupManager_65a9107d, XFilterManager_16f30e70, XCancellable_afc30b64):
    """
    Provides unified interface for FilePicker service.
    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API XFilePicker3 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker3.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui.dialogs'
    __ooo_full_ns__: str = 'com.sun.star.ui.dialogs.XFilePicker3'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.dialogs.XFilePicker3'


__all__ = ['XFilePicker3']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ui
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class LayoutSize(object):
    """
    Struct Class

    Size used for layouting windows.
    
    It specifies a range of valid values and a preferred value. The values must not violate the relation 0 â¤ Minimum â¤ Preferred â¤ Maximum.

    See Also:
        `API LayoutSize <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ui_1_1LayoutSize.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.LayoutSize'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ui.LayoutSize'
    """Literal Constant ``com.sun.star.ui.LayoutSize``"""

    def __init__(self, Minimum: typing.Optional[int] = 0, Maximum: typing.Optional[int] = 0, Preferred: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Minimum (int, optional): Minimum value.
            Maximum (int, optional): Maximum value.
            Preferred (int, optional): Preferred value.
        """
        super().__init__()

        if isinstance(Minimum, LayoutSize):
            oth: LayoutSize = Minimum
            self.Minimum = oth.Minimum
            self.Maximum = oth.Maximum
            self.Preferred = oth.Preferred
            return

        kargs = {
            "Minimum": Minimum,
            "Maximum": Maximum,
            "Preferred": Preferred,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._minimum = kwargs["Minimum"]
        self._maximum = kwargs["Maximum"]
        self._preferred = kwargs["Preferred"]


    @property
    def Minimum(self) -> int:
        return self._minimum

    @Minimum.setter
    def Minimum(self, value: int) -> None:
        self._minimum = value

    @property
    def Maximum(self) -> int:
        return self._maximum

    @Maximum.setter
    def Maximum(self, value: int) -> None:
        self._maximum = value

    @property
    def Preferred(self) -> int:
        return self._preferred

    @Preferred.setter
    def Preferred(self, value: int) -> None:
        self._preferred = value


__all__ = ['LayoutSize']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.view
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..awt.size import Size as Size_576707ef
    from com.sun.star.view.PaperFormat import PaperFormatProto
    from com.sun.star.view.PaperOrientation import PaperOrientationProto

class PrinterDescriptor(ABC):
    """
    Service Class

    describes a printer by specifying the queue name and some settings.
    
    This service may be represented by a com.sun.star.beans.PropertyValue[].

    See Also:
        `API PrinterDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1view_1_1PrinterDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.view'
    __ooo_full_ns__: str = 'com.sun.star.view.PrinterDescriptor'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CanSetPaperFormat(self) -> bool:
        """
        indicates, whether the printer allows changes to PrinterDescriptor.PaperFormat.
        """
        ...

    @abstractproperty
    def CanSetPaperOrientation(self) -> bool:
        """
        indicates, whether the printer allows changes to PrinterDescriptor.PaperOrientation.
        """
        ...

    @abstractproperty
    def CanSetPaperSize(self) -> bool:
        """
        indicates if the printer allows changes to PrinterDescriptor.PaperSize.
        """
        ...

    @abstractproperty
    def IsBusy(self) -> bool:
        """
        indicates, whether the printer is busy or not.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        specifies the name of the printer queue to be used.
        
        Which printer queues are available, can be figured out with the system library of the used programming language/environment.
        """
        ...

    @abstractproperty
    def PaperFormat(self) -> PaperFormatProto:
        """
        specifies a predefined paper size or if the paper size is a user-defined size.
        
        Setting this property may change the value of PrinterDescriptor.PaperSize.
        """
        ...

    @abstractproperty
    def PaperOrientation(self) -> PaperOrientationProto:
        """
        specifies the orientation of the paper.
        """
        ...

    @abstractproperty
    def PaperSize(self) -> Size_576707ef:
        """
        specifies the size of the paper in 100th mm.
        
        Setting this property may change the value of PrinterDescriptor.PaperFormat.
        """
        ...


__all__ = ['PrinterDescriptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.accessibility


class AccessibleStateType(object):
    """
    Const Class

    Collection of state types.
    
    This list of constants defines the available set of states that an object that implements XAccessibleContext can be in.
    
    The comments describing the states is taken verbatim from the Java Accessibility API 1.4 documentation.
    
    We are using constants instead of a more typesafe enum. The reason for this is that IDL enums may not be extended. Therefore, in order to include future extensions to the set of roles we have to use constants here.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleStateType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1accessibility_1_1AccessibleStateType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.accessibility'
    __ooo_full_ns__: str = 'com.sun.star.accessibility.AccessibleStateType'
    __ooo_type_name__: str = 'const'

    INVALID = 0
    """
    Indicates an invalid state.
    """
    ACTIVE = 1
    """
    Indicates a window is currently the active window.
    """
    ARMED = 2
    """
    Indicates that the object is armed.
    """
    BUSY = 3
    """
    Indicates the current object is busy.
    """
    CHECKED = 4
    """
    Indicates this object is currently checked.
    """
    DEFUNC = 5
    """
    User interface object corresponding to this object no longer exists.
    
    Indicates the user interface object corresponding to this object no longer exists.
    """
    EDITABLE = 6
    """
    Indicates the user can change the contents of this object.
    """
    ENABLED = 7
    """
    Indicates this object is enabled.
    """
    EXPANDABLE = 8
    """
    Indicates this object allows progressive disclosure of its children.
    """
    EXPANDED = 9
    """
    Indicates this object is expanded.
    """
    FOCUSABLE = 10
    """
    Object can accept the keyboard focus.
    
    Indicates this object can accept keyboard focus, which means all events resulting from typing on the keyboard will normally be passed to it when it has focus.
    """
    FOCUSED = 11
    """
    Indicates this object currently has the keyboard focus.
    """
    HORIZONTAL = 12
    """
    Indicates the orientation of this object is horizontal.
    """
    ICONIFIED = 13
    """
    Indicates this object is minimized and is represented only by an icon.
    """
    INDETERMINATE = 14
    """
    Sometimes UI elements can have a state indeterminate.
    
    This can happen e.g. if a check box reflects the bold state of text in a text processor. When the current selection contains text which is bold and also text which is not bold, the state is indeterminate.
    """
    MANAGES_DESCENDANTS = 15
    """
    Indicates the most (all) children are transient and it is not necessary to add listener to the children.
    
    Only the active descendant (given by the event) should be not transient to make it possible to add listener to this object and recognize changes in this object.
    
    The state is added to make a performance improvement. Now it is no longer necessary to iterate over all children to find out whether they are transient or not to decide whether to add listener or not. If there is an object with this state no one should iterate over the children to add listener. Only the active descendant should get listener if it is not transient.
    """
    MODAL = 16
    """
    Object is modal.
    
    Indicates something must be done with this object before the user can interact with an object in a different window.
    """
    MULTI_LINE = 17
    """
    Indicates this (text) object can contain multiple lines of text.
    """
    MULTI_SELECTABLE = 18
    """
    More than one child may be selected at the same time.
    
    Indicates this object allows more than one of its children to be selected at the same time.
    """
    OPAQUE = 19
    """
    Indicates this object paints every pixel within its rectangular region.
    """
    PRESSED = 20
    """
    Indicates this object is currently pressed.
    """
    RESIZABLE = 21
    """
    Indicates the size of this object is not fixed.
    """
    SELECTABLE = 22
    """
    Object is selectable.
    
    Indicates this object is the child of an object that allows its children to be selected, and that this child is one of those children that can be selected.
    """
    SELECTED = 23
    """
    Object is selected.
    
    Indicates this object is the child of an object that allows its children to be selected, and that this child is one of those children that has been selected.
    """
    SENSITIVE = 24
    """
    Indicates this object is sensitive.
    """
    SHOWING = 25
    """
    Object is displayed on the screen.
    
    An object has set the SHOWING state if itself and all of its parents have set the VISIBLE state and it lies at least partly inside the visible area of its parent. It is, though, not necessarily visible on the screen because it may be occluded by other objects.
    """
    SINGLE_LINE = 26
    """
    Indicates this (text) object can contain only a single line of text.
    """
    STALE = 27
    """
    Object information is stale and might not be up to date.
    
    Indicates that the information that is returned from this object might be out of sync with the application.
    """
    TRANSIENT = 28
    """
    Indicates this object is transient.
    """
    VERTICAL = 29
    """
    Indicates the orientation of this object is vertical.
    """
    VISIBLE = 30
    """
    Object wants to be displayed on the screen.
    
    A set VISIBLE state indicates that an object wants to be displayed on the screen. It is displayed, as indicated by a set SHOWING state, if all of its parents have also set the VISIBLE state and the object lies at least partly in the visible area of its parent.
    """
    MOVEABLE = 31
    """
    Indicates the position of the object is not fixed.
    """
    DEFAULT = 32
    """
    Indicates the object is the default button in a window.
    """
    OFFSCREEN = 33
    """
    Indicates the object is outside of the screen area.
    """
    COLLAPSE = 34
    """
    Indicates that the object is collapsed.
    """

__all__ = ['AccessibleStateType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .outgoing_message_state import OutgoingMessageState as OutgoingMessageState_c200e54


class RecipientInfo(object):
    """
    Struct Class

    contains all information needed to send a message using one send protocol.
    
    To send one message via two different protocols, two RecipientInfos are needed - to send one message to different users with one protocol, one RecipientInfo can be used.

    See Also:
        `API RecipientInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1RecipientInfo.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.RecipientInfo'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.RecipientInfo'
    """Literal Constant ``com.sun.star.ucb.RecipientInfo``"""

    def __init__(self, ProtocolType: typing.Optional[str] = '', State: typing.Optional[OutgoingMessageState_c200e54] = OutgoingMessageState_c200e54.WRITTEN, To: typing.Optional[str] = '', CC: typing.Optional[str] = '', BCC: typing.Optional[str] = '', Newsgroups: typing.Optional[str] = '', Server: typing.Optional[str] = '', Username: typing.Optional[str] = '', Password: typing.Optional[str] = '', VIMPostOfficePath: typing.Optional[str] = '', ProtocolErrorString: typing.Optional[str] = '', ProtocolErrorNumber: typing.Optional[int] = 0, SendTries: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            ProtocolType (str, optional): ProtocolType value.
            State (OutgoingMessageState, optional): State value.
            To (str, optional): To value.
            CC (str, optional): CC value.
            BCC (str, optional): BCC value.
            Newsgroups (str, optional): Newsgroups value.
            Server (str, optional): Server value.
            Username (str, optional): Username value.
            Password (str, optional): Password value.
            VIMPostOfficePath (str, optional): VIMPostOfficePath value.
            ProtocolErrorString (str, optional): ProtocolErrorString value.
            ProtocolErrorNumber (int, optional): ProtocolErrorNumber value.
            SendTries (int, optional): SendTries value.
        """
        super().__init__()

        if isinstance(ProtocolType, RecipientInfo):
            oth: RecipientInfo = ProtocolType
            self.ProtocolType = oth.ProtocolType
            self.State = oth.State
            self.To = oth.To
            self.CC = oth.CC
            self.BCC = oth.BCC
            self.Newsgroups = oth.Newsgroups
            self.Server = oth.Server
            self.Username = oth.Username
            self.Password = oth.Password
            self.VIMPostOfficePath = oth.VIMPostOfficePath
            self.ProtocolErrorString = oth.ProtocolErrorString
            self.ProtocolErrorNumber = oth.ProtocolErrorNumber
            self.SendTries = oth.SendTries
            return

        kargs = {
            "ProtocolType": ProtocolType,
            "State": State,
            "To": To,
            "CC": CC,
            "BCC": BCC,
            "Newsgroups": Newsgroups,
            "Server": Server,
            "Username": Username,
            "Password": Password,
            "VIMPostOfficePath": VIMPostOfficePath,
            "ProtocolErrorString": ProtocolErrorString,
            "ProtocolErrorNumber": ProtocolErrorNumber,
            "SendTries": SendTries,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._protocol_type = kwargs["ProtocolType"]
        self._state = kwargs["State"]
        self._to = kwargs["To"]
        self._cc = kwargs["CC"]
        self._bcc = kwargs["BCC"]
        self._newsgroups = kwargs["Newsgroups"]
        self._server = kwargs["Server"]
        self._username = kwargs["Username"]
        self._password = kwargs["Password"]
        self._vim_post_office_path = kwargs["VIMPostOfficePath"]
        self._protocol_error_string = kwargs["ProtocolErrorString"]
        self._protocol_error_number = kwargs["ProtocolErrorNumber"]
        self._send_tries = kwargs["SendTries"]


    @property
    def ProtocolType(self) -> str:
        """
        the protocol to use for sending (i.e.
        
        \"NNTP\", \"SMTP\", \"VIM\").
        """
        return self._protocol_type

    @ProtocolType.setter
    def ProtocolType(self, value: str) -> None:
        self._protocol_type = value

    @property
    def State(self) -> OutgoingMessageState_c200e54:
        """
        the current state of the message.
        """
        return self._state

    @State.setter
    def State(self, value: OutgoingMessageState_c200e54) -> None:
        self._state = value

    @property
    def To(self) -> str:
        """
        the recipient(s) (e.g.
        
        e-mail address/es).
        
        Multiple addresses are separated by commas.
        """
        return self._to

    @To.setter
    def To(self, value: str) -> None:
        self._to = value

    @property
    def CC(self) -> str:
        """
        the recipient(s) of a \"carbon copy\" (e.g.
        
        e-mail address/es).
        
        Multiple addresses are separated by commas.
        """
        return self._cc

    @CC.setter
    def CC(self, value: str) -> None:
        self._cc = value

    @property
    def BCC(self) -> str:
        """
        the recipient(s) of \"blind carbon copy\" (e.g.
        
        e-mail address/es).
        
        Multiple addresses are separated by commas.
        """
        return self._bcc

    @BCC.setter
    def BCC(self, value: str) -> None:
        self._bcc = value

    @property
    def Newsgroups(self) -> str:
        """
        the newsgroup(s) to which an article is be posted.
        
        Multiple addresses are separated by commas.
        """
        return self._newsgroups

    @Newsgroups.setter
    def Newsgroups(self, value: str) -> None:
        self._newsgroups = value

    @property
    def Server(self) -> str:
        """
        the name of the server to be used for sending the message.
        """
        return self._server

    @Server.setter
    def Server(self, value: str) -> None:
        self._server = value

    @property
    def Username(self) -> str:
        """
        the user name to be used for authorizing on the send server.
        """
        return self._username

    @Username.setter
    def Username(self, value: str) -> None:
        self._username = value

    @property
    def Password(self) -> str:
        """
        the password to be used for authorizing on the send server.
        """
        return self._password

    @Password.setter
    def Password(self, value: str) -> None:
        self._password = value

    @property
    def VIMPostOfficePath(self) -> str:
        """
        the Post Office Path (VIM only).
        """
        return self._vim_post_office_path

    @VIMPostOfficePath.setter
    def VIMPostOfficePath(self, value: str) -> None:
        self._vim_post_office_path = value

    @property
    def ProtocolErrorString(self) -> str:
        """
        string representing the last error (generated by send server).
        """
        return self._protocol_error_string

    @ProtocolErrorString.setter
    def ProtocolErrorString(self, value: str) -> None:
        self._protocol_error_string = value

    @property
    def ProtocolErrorNumber(self) -> int:
        """
        the number representing the last error (generated by send server).
        """
        return self._protocol_error_number

    @ProtocolErrorNumber.setter
    def ProtocolErrorNumber(self, value: int) -> None:
        self._protocol_error_number = value

    @property
    def SendTries(self) -> int:
        """
        the count of tries to send a message.
        
        This count is 1 if the message was sent with the first try and increases with every unsuccessful retry.
        """
        return self._send_tries

    @SendTries.setter
    def SendTries(self, value: int) -> None:
        self._send_tries = value


__all__ = ['RecipientInfo']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class TransferResult(object):
    """
    Struct Class

    Information about a transfer activity.

    See Also:
        `API TransferResult <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1TransferResult.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.TransferResult'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.TransferResult'
    """Literal Constant ``com.sun.star.ucb.TransferResult``"""

    def __init__(self, Source: typing.Optional[str] = '', Target: typing.Optional[str] = '', Result: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            Source (str, optional): Source value.
            Target (str, optional): Target value.
            Result (object, optional): Result value.
        """
        super().__init__()

        if isinstance(Source, TransferResult):
            oth: TransferResult = Source
            self.Source = oth.Source
            self.Target = oth.Target
            self.Result = oth.Result
            return

        kargs = {
            "Source": Source,
            "Target": Target,
            "Result": Result,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._source = kwargs["Source"]
        self._target = kwargs["Target"]
        self._result = kwargs["Result"]


    @property
    def Source(self) -> str:
        """
        The URL of the source object.
        """
        return self._source

    @Source.setter
    def Source(self, value: str) -> None:
        self._source = value

    @property
    def Target(self) -> str:
        """
        The URL of the target folder into which to transfer (a copy of) the source object.
        """
        return self._target

    @Target.setter
    def Target(self, value: str) -> None:
        self._target = value

    @property
    def Result(self) -> object:
        """
        Either void if the transfer has been carried out successfully, or an exception indicating the kind of failure.
        """
        return self._result

    @Result.setter
    def Result(self, value: object) -> None:
        self._result = value


__all__ = ['TransferResult']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text.textfield.docinfo
from __future__ import annotations
from abc import abstractproperty
from ...text_field import TextField as TextField_90260a56

class Custom(TextField_90260a56):
    """
    Service Class

    specifies service of a text field that refers to the content of a user-defined field in the document information.
    
    **since**
    
        OOo 3.0

    See Also:
        `API Custom <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1Custom.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text.textfield.docinfo'
    __ooo_full_ns__: str = 'com.sun.star.text.textfield.docinfo.Custom'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CurrentPresentation(self) -> str:
        """
        contains the current content of the text field.
        
        This property is useful for import/export purposes.
        """
        ...

    @abstractproperty
    def IsFixed(self) -> bool:
        """
        If this flag is set to FALSE, the content is updated when the document information changes.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        the name of the user-defined property that this field refers to.
        """
        ...


__all__ = ['Custom']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class TextConversionOption(metaclass=UnoConstMeta, type_name="com.sun.star.i18n.TextConversionOption", name_space="com.sun.star.i18n"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.i18n.TextConversionOption``"""
        pass

    class TextConversionOptionEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.i18n.TextConversionOption", name_space="com.sun.star.i18n"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.i18n.TextConversionOption`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.i18n import TextConversionOption as TextConversionOption
    else:
        # keep document generators happy
        from ...lo.i18n.text_conversion_option import TextConversionOption as TextConversionOption

    class TextConversionOptionEnum(IntEnum):
        """
        Enum of Const Class TextConversionOption

        Text conversion options to be used with XTextConversion.
        
        These text conversion options are usually selected by end users. The options can be combined and may be related to TextConversionType.
        
        **since**
        
            OOo 1.1.2
        """
        NONE = TextConversionOption.NONE
        """
        No option.
        """
        CHARACTER_BY_CHARACTER = TextConversionOption.CHARACTER_BY_CHARACTER
        """
        Character by character conversion.
        """
        IGNORE_POST_POSITIONAL_WORD = TextConversionOption.IGNORE_POST_POSITIONAL_WORD
        """
        Ignore post-positional word for Hangul to Hanja conversion.
        """
        USE_CHARACTER_VARIANTS = TextConversionOption.USE_CHARACTER_VARIANTS
        """
        Use Taiwan, HongKong SAR, and Macao SAR character variants for Simplified to Traditional Chinese conversion.
        
        **since**
        
            OOo 2.0
        """

__all__ = ['TextConversionOption', 'TextConversionOptionEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .font_metrics import FontMetrics as FontMetrics_e4540d34
    from .font_request import FontRequest as FontRequest_e4890d46
    from .string_context import StringContext as StringContext_d50e22
    from .x_text_layout import XTextLayout as XTextLayout_e44a0d41

class XCanvasFont(XInterface_8f010a43):
    """
    This interface provides access to a specific, XCanvas-dependent font incarnation.
    
    This font is not universally usable, but belongs to the XCanvas it was queried from.

    See Also:
        `API XCanvasFont <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvasFont.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.XCanvasFont'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rendering.XCanvasFont'

    @abstractmethod
    def createTextLayout(self, aText: StringContext_d50e22, nDirection: int, nRandomSeed: int) -> XTextLayout_e44a0d41:
        """
        Create a text layout interface.
        
        Create a text layout interface for the given string, using this font to generate the glyphs from.
        """
        ...
    @abstractmethod
    def getAvailableSizes(self) -> typing.Tuple[float, ...]:
        """
        Query the list of available font sizes.
        
        This method queries the list of available font sizes (in device units) for this font. For scalable fonts that are not restricted to discrete sizes, this list is empty, meaning that every size is possible. Fonts that do restrict the device size to certain discrete values, setting an overall transformation that scales the FontRequest.CellSize to something not contained in the list returned by this method can lead to visible disturbances.
        """
        ...
    @abstractmethod
    def getExtraFontProperties(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        Query the list of additional font properties.
        """
        ...
    @abstractmethod
    def getFontMetrics(self) -> FontMetrics_e4540d34:
        """
        Query metric information about the font, that is generic to all its glyphs.
        
        Note that the metric values in the returned result are in the font coordinate system, i.e. relative to the corresponding size of this font. That is, when this font was created with a cell size of 20 units, the metrics returned are calculated relative to this size.
        """
        ...
    @abstractmethod
    def getFontRequest(self) -> FontRequest_e4890d46:
        """
        Query the FontRequest that was used to generate this object.
        """
        ...

__all__ = ['XCanvasFont']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class SystemDependentXWindow(object):
    """
    Struct Class

    specifies a system dependent XWindow.
    
    This is the structure returned in the XSystemDependentWindowPeer.getWindowHandle() call, if the system type is com.sun.star.lang.SystemDependent.XWINDOW.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API SystemDependentXWindow <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1SystemDependentXWindow.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.SystemDependentXWindow'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.awt.SystemDependentXWindow'
    """Literal Constant ``com.sun.star.awt.SystemDependentXWindow``"""

    def __init__(self, WindowHandle: typing.Optional[int] = 0, DisplayPointer: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            WindowHandle (int, optional): WindowHandle value.
            DisplayPointer (int, optional): DisplayPointer value.
        """
        super().__init__()

        if isinstance(WindowHandle, SystemDependentXWindow):
            oth: SystemDependentXWindow = WindowHandle
            self.WindowHandle = oth.WindowHandle
            self.DisplayPointer = oth.DisplayPointer
            return

        kargs = {
            "WindowHandle": WindowHandle,
            "DisplayPointer": DisplayPointer,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._window_handle = kwargs["WindowHandle"]
        self._display_pointer = kwargs["DisplayPointer"]


    @property
    def WindowHandle(self) -> int:
        """
        The XWindow handle if possible, otherwise 0.
        """
        return self._window_handle

    @WindowHandle.setter
    def WindowHandle(self, value: int) -> None:
        self._window_handle = value

    @property
    def DisplayPointer(self) -> int:
        """
        The display pointer.
        """
        return self._display_pointer

    @DisplayPointer.setter
    def DisplayPointer(self, value: int) -> None:
        self._display_pointer = value


__all__ = ['SystemDependentXWindow']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.linguistic2
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .dictionary_event import DictionaryEvent as DictionaryEvent_3ae00f8d


class DictionaryListEvent(EventObject_a3d70b03):
    """
    Struct Class

    structure representing a dictionary-list event.
    
    This structure is used by the dictionary-list to inform its listeners about certain events. Since the dictionary-list is able to collect several single events before broadcasting them to its listeners the integer argument may be a combination (logical or) of several event types. If more specific information about the events is requested by a listener, a sequence of all dictionary-list events since the last broadcasting will be supplied. Otherwise, that list will be empty.

    See Also:
        `API DictionaryListEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1linguistic2_1_1DictionaryListEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.DictionaryListEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.linguistic2.DictionaryListEvent'
    """Literal Constant ``com.sun.star.linguistic2.DictionaryListEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, aDictionaryEvents: typing.Optional[typing.Tuple[DictionaryEvent_3ae00f8d, ...]] = (), nCondensedEvent: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            aDictionaryEvents (typing.Tuple[DictionaryEvent, ...], optional): aDictionaryEvents value.
            nCondensedEvent (int, optional): nCondensedEvent value.
        """

        if isinstance(Source, DictionaryListEvent):
            oth: DictionaryListEvent = Source
            self.Source = oth.Source
            self.aDictionaryEvents = oth.aDictionaryEvents
            self.nCondensedEvent = oth.nCondensedEvent
            return

        kargs = {
            "Source": Source,
            "aDictionaryEvents": aDictionaryEvents,
            "nCondensedEvent": nCondensedEvent,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._a_dictionary_events = kwargs["aDictionaryEvents"]
        self._n_condensed_event = kwargs["nCondensedEvent"]
        inst_keys = ('aDictionaryEvents', 'nCondensedEvent')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def aDictionaryEvents(self) -> typing.Tuple[DictionaryEvent_3ae00f8d, ...]:
        """
        list of accumulated dictionary events.
        
        It will be empty if all com.sun.star.linguistic2.XDictionaryListEventListener are satisfied with the condensed representation of the com.sun.star.linguistic2.DictionaryListEvent.nCondensedEvent().
        """
        return self._a_dictionary_events

    @aDictionaryEvents.setter
    def aDictionaryEvents(self, value: typing.Tuple[DictionaryEvent_3ae00f8d, ...]) -> None:
        self._a_dictionary_events = value

    @property
    def nCondensedEvent(self) -> int:
        """
        the combined type of the accumulated events.
        
        The value can be the combination of multiple com.sun.star.linguistic2.DictionaryListEventFlags by applying the logical OR to them.
        """
        return self._n_condensed_event

    @nCondensedEvent.setter
    def nCondensedEvent(self, value: int) -> None:
        self._n_condensed_event = value


__all__ = ['DictionaryListEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_sheet_cell_ranges import XSheetCellRanges as XSheetCellRanges_edef0d52
if typing.TYPE_CHECKING:
    from ..table.cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43

class XSheetCellRangeContainer(XSheetCellRanges_edef0d52):
    """
    provides methods to access cell ranges in a collection via index and to add and remove cell ranges.

    See Also:
        `API XSheetCellRangeContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCellRangeContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XSheetCellRangeContainer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XSheetCellRangeContainer'

    @abstractmethod
    def addRangeAddress(self, aCellRangeAddress: CellRangeAddress_ec450d43, bMergeRanges: bool) -> None:
        """
        adds the given range to the collection of cell ranges.
        """
        ...
    @abstractmethod
    def addRangeAddresses(self, aCellRangeAddresses: typing.Tuple[CellRangeAddress_ec450d43, ...], bMergeRanges: bool) -> None:
        """
        adds the given ranges to the collection of cell ranges.
        """
        ...
    @abstractmethod
    def removeRangeAddress(self, aCellRangeAddress: CellRangeAddress_ec450d43) -> None:
        """
        removes the given range from the collection of cell ranges.
        
        The specified range must fit exactly to an element of the collection. The method does not try to shorten a range.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def removeRangeAddresses(self, aCellRangeAddresses: typing.Tuple[CellRangeAddress_ec450d43, ...]) -> None:
        """
        removes the given ranges from the collection of cell ranges.
        
        All specified ranges must fit exactly to elements of the collection. The method does not try to shorten ranges.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...

__all__ = ['XSheetCellRangeContainer']

